@@ -5,8 +5,8 @@
     assignments, and much more.
 """
 
-__author__ = "James Turk (jturk@sunlightfoundation.com)"
-__version__ = "0.2.1"
+__author__ = "James Turk <jturk@sunlightfoundation.com>"
+__version__ = "0.3.0"
 __copyright__ = "Copyright (c) 2009 Sunlight Labs"
 __license__ = "BSD"
 
@@ -22,13 +22,19 @@ class VotesmartApiError(Exception):
 class VotesmartApiObject(object):
     def __init__(self, d):
         self.__dict__ = d
+
+    def __repr__(self):
+        return '%s(%r)' % (self.__class__.__name__, self.__dict__)
         
 class Address(object):
     def __init__(self, d):
         self.__dict__.update(d['address'])
         self.__dict__.update(d['phone'])
         self.__dict__.update(d['notes'])
-    
+
+    def __repr__(self):
+        return '%s(%r)' % (self.__class__.__name__, self.__dict__)
+
 class WebAddress(VotesmartApiObject):
     def __str__(self):
         return self.webAddress
@@ -38,6 +44,9 @@ class Bio(object):
         #self.__dict__.update(d['election'])
         #self.__dict__.update(d['office'])
         self.__dict__.update(d['candidate'])
+
+    def __repr__(self):
+        return '%s(%r)' % (self.__class__.__name__, self.__dict__)
     
 class AddlBio(VotesmartApiObject):
     def __str__(self):
@@ -69,10 +78,10 @@ class District(VotesmartApiObject):
     
 class Election(VotesmartApiObject):
     def __init__(self, d):
-        stages = [ElectionStage(s) for s in d.pop('stage')]
+        stages = d.pop('stage')
         self.__dict__ = d
-        self.stages = stages
-    
+        self.stages = _result_to_obj(ElectionStage, stages)
+
     def __str__(self):
         return self.name
     
@@ -170,7 +179,7 @@ class BillActionDetail(VotesmartApiObject):
 class Bill(VotesmartApiObject):
     def __str__(self):
         return ' '.join((self.billNumber, self.title))
-        
+
 class Vote(VotesmartApiObject):
     def __str__(self):
         return ': '.join((self.candidateName, self.action))
@@ -290,6 +299,12 @@ class votesmart(object):
             params = {'districtId': districtId, 'electionYear':electionYear}
             result = votesmart._apicall('Candidates.getByDistrict', params)
             return _result_to_obj(Candidate, result['candidateList']['candidate'])
+
+        @staticmethod
+        def getByZip(zip5, zip4=None):
+            params = {'zip4': zip4, 'zip5': zip5}
+            result = votesmart._apicall('Candidates.getByZip', params)
+            return _result_to_obj(Candidate, result['candidateList']['candidate'])
         
     class committee(object):
         @staticmethod
@@ -321,6 +336,12 @@ class votesmart(object):
             params = {'officeId':officeId, 'stateId': stateId, 'districtName': districtName}
             result = votesmart._apicall('District.getByOfficeState', params)
             return _result_to_obj(District, result['districtList']['district'])
+
+        @staticmethod
+        def getByZip(zip5, zip4=None):
+            params = {'zip5': zip5, 'zip4': zip4}
+            result = votesmart._apicall('District.getByZip', params)
+            return _result_to_obj(District, result['districtList']['district'])
     
     class election(object):
         @staticmethod
@@ -334,6 +355,12 @@ class votesmart(object):
             params = {'year':year, 'stateId':stateId}
             result = votesmart._apicall('Election.getElectionByYearState', params)
             return _result_to_obj(Election, result['elections']['election'])
+
+        @staticmethod
+        def getElectionByZip(zip5, zip4=None, year=None):
+            params = {'zip5': zip5, 'zip4': zip4, 'year': year}
+            result = votesmart._apicall('Election.getElectionByZip', params)
+            return _result_to_obj(Election, result['elections']['election'])
             
         #@staticmethod
         #def getStageCandidates(electionId, stageId,
@@ -436,6 +463,12 @@ class votesmart(object):
             return _result_to_obj(Office, result['offices']['office'])
                 
     class officials(object):
+        @staticmethod
+        def getStatewide(stateId=None):
+            params = {'stateId': stateId}
+            result = votesmart._apicall('Officials.getStatewide', params)
+            return _result_to_obj(Official, result['candidateList']['candidate'])
+
         @staticmethod
         def getByOfficeState(officeId, stateId=None):
             params = {'officeId':officeId, 'stateId': stateId}
@@ -465,6 +498,12 @@ class votesmart(object):
             params = {'districtId':districtId}
             result = votesmart._apicall('Officials.getByDistrict', params)
             return _result_to_obj(Official, result['candidateList']['candidate'])
+
+        @staticmethod
+        def getByZip(zip5, zip4=None):
+            params = {'zip4': zip4, 'zip5': zip5}
+            result = votesmart._apicall('Officials.getByZip', params)
+            return _result_to_obj(Official, result['candidateList']['candidate'])
     
     class rating(object):
         @staticmethod
@@ -533,6 +572,12 @@ class votesmart(object):
             params = {'actionId':actionId, 'candidateId':candidateId}
             result = votesmart._apicall('Votes.getBillActionVoteByOfficial', params)
             return Vote(result['votes']['vote'])
+
+        @staticmethod
+        def getByBillNumber(billNumber):
+            params = {'billNumber': billNumber}
+            result = votesmart._apicall('Votes.getByBillNumber', params)
+            return _result_to_obj(Bill, result['bills']['bill'])
             
         @staticmethod
         def getBillsByCategoryYearState(categoryId, year, stateId=None):
